==> flyyfluttersdk-1.0.0%2B1.tar.gz: lib/helpers/FlyyOffersAndRewardsBalanceList.dart <==
import 'package:flutter/material.dart';
import 'package:flyyfluttersdk/helpers/FlyyUtility.dart';
import 'package:flyyfluttersdk/model/FlyyWalletCompleteData.dart';

class FlyyOffersAndRewardsBalanceList extends StatefulWidget {
  @override
  State<StatefulWidget> createState() {
    return new FlyyBalanceListViewState();
  }
}

class FlyyBalanceListViewState extends State<FlyyOffersAndRewardsBalanceList> {
  List<FlyyWalletCompleteData> balanceList = new List();

  @override
  void initState() {
    super.initState();
    setState(() {
      balanceList.addAll(FlyyUtility.flyyWalletCompleteDataList);
    });
  }

  @override
  Widget build(BuildContext context) {
    return loadBalanceListView();
  }

  static Widget loadBalanceListView() {
    return Expanded(
      child: SizedBox(
        height: 80,
        width: 150,
        child: ListView.builder(
          itemBuilder: setBalancesListView,
          itemCount: FlyyUtility.flyyWalletCompleteDataList.length,
          scrollDirection: Axis.horizontal,
          shrinkWrap: true,
        ),
      ),
    );
  }

  ///List view inner layout
  static Widget setBalancesListView(BuildContext context, int index) {
    FlyyWalletCompleteData flyyWalletCompleteData =
        FlyyUtility.flyyWalletCompleteDataList[index];
    var iconUrl = flyyWalletCompleteData.rewardIcon;
    var label = flyyWalletCompleteData.rewardType;
    var balanceVal = flyyWalletCompleteData.balance;
    if (iconUrl != null && iconUrl.isNotEmpty) {
      return Container(
        margin: const EdgeInsets.only(right: 5),
        child: Column(
          children: <Widget>[
            Card(
              shape: RoundedRectangleBorder(
                borderRadius: BorderRadius.circular(15),
              ),
              child: Padding(
                padding: const EdgeInsets.only(left: 10, right: 10),
                child: Row(
                  children: <Widget>[
                    Padding(
                      padding: const EdgeInsets.only(left: 5),
                      child: Image(
                        image: NetworkImage(iconUrl),
                        fit: BoxFit.fill,
                        width: 15,
                        height: 15,
                      ),
                    ),
                    Padding(
                      padding: const EdgeInsets.only(
                          left: 5, right: 10, top: 10, bottom: 10),
                      child: Text(
                        balanceVal.toString(),
                        style: new TextStyle(
                            fontSize: 12,
                            color: FlyyUtility.parseColor('#736c6c')),
                      ),
                    ),
                  ],
                ),
              ),
            ),
            Container(
              alignment: Alignment.center,
              child: Text(
                flyyWalletCompleteData.rewardType,
                style: new TextStyle(fontSize: 12, color: Colors.white),
              ),
            )
          ],
        ),
      );
    } else {
      return Container(
        margin: const EdgeInsets.only(left: 10),
        child: Column(
          children: <Widget>[
            Container(
              margin: const EdgeInsets.only(bottom: 5),
              decoration: BoxDecoration(
                border: Border.all(
                  color: Colors.white,
                ),
                borderRadius: BorderRadius.circular(15),
              ),
              child: Padding(
                padding: const EdgeInsets.all(10),
                child: Text(
                  label == 'Cash'
                      ? '₹' + balanceVal.toString()
                      : balanceVal.toString() + ' ' + label,
                  style: new TextStyle(fontSize: 12, color: Colors.white),
                ),
              ),
            ),
            Text(
              flyyWalletCompleteData.rewardType,
              style: new TextStyle(fontSize: 12, color: Colors.white),
            )
          ],
        ),
      );
    }
  }
}

==> flyyfluttersdk-1.0.1%2B1.tar.gz: lib/helpers/FlyyOffersAndRewardsBalanceList.dart <==
import 'package:flutter/material.dart';
import 'package:flyyfluttersdk/helpers/FlyyUtility.dart';
import 'package:flyyfluttersdk/model/FlyyWalletCompleteData.dart';

class FlyyOffersAndRewardsBalanceList extends StatefulWidget {
  @override
  State<StatefulWidget> createState() {
    return new FlyyBalanceListViewState();
  }
}

class FlyyBalanceListViewState extends State<FlyyOffersAndRewardsBalanceList> {
  List<FlyyWalletCompleteData> balanceList = new List();

  @override
  void initState() {
    super.initState();
    setState(() {
      balanceList.addAll(FlyyUtility.flyyWalletCompleteDataList);
    });
  }

  @override
  Widget build(BuildContext context) {
    return loadBalanceListView();
  }

  Widget loadBalanceListView() {
    return Expanded(
      child: SizedBox(
        height: 80,
        width: 150,
        child: ListView.builder(
          itemBuilder: setBalancesListView,
          itemCount: FlyyUtility.flyyWalletCompleteDataList.length,
          scrollDirection: Axis.horizontal,
          shrinkWrap: true,
        ),
      ),
    );
  }

  ///List view inner layout
  Widget setBalancesListView(BuildContext context, int index) {
    FlyyWalletCompleteData flyyWalletCompleteData =
        FlyyUtility.flyyWalletCompleteDataList[index];
    var iconUrl = flyyWalletCompleteData.rewardIcon;
    var label = flyyWalletCompleteData.rewardType;
    var balanceVal = flyyWalletCompleteData.balance;
    if (iconUrl != null && iconUrl.isNotEmpty) {
      return Container(
        margin: const EdgeInsets.only(right: 5),
        child: Column(
          children: <Widget>[
            Card(
              shape: RoundedRectangleBorder(
                borderRadius: BorderRadius.circular(15),
              ),
              child: Padding(
                padding: const EdgeInsets.only(left: 10, right: 10),
                child: Row(
                  children: <Widget>[
                    Padding(
                      padding: const EdgeInsets.only(left: 5),
                      child: Image(
                        image: NetworkImage(iconUrl),
                        fit: BoxFit.fill,
                        width: 15,
                        height: 15,
                      ),
                    ),
                    Padding(
                      padding: const EdgeInsets.only(
                          left: 5, right: 10, top: 10, bottom: 10),
                      child: Text(
                        balanceVal.toString(),
                        style: new TextStyle(
                            fontSize: 12,
                            color: FlyyUtility.parseColor('#736c6c')),
                      ),
                    ),
                  ],
                ),
              ),
            ),
            Container(
              alignment: Alignment.center,
              child: Text(
                flyyWalletCompleteData.rewardType,
                style: new TextStyle(fontSize: 12, color: Colors.white),
              ),
            )
          ],
        ),
      );
    } else {
      return Container(
        margin: const EdgeInsets.only(left: 10),
        child: Column(
          children: <Widget>[
            Container(
              margin: const EdgeInsets.only(bottom: 5),
              decoration: BoxDecoration(
                border: Border.all(
                  color: Colors.white,
                ),
                borderRadius: BorderRadius.circular(15),
              ),
              child: Padding(
                padding: const EdgeInsets.all(10),
                child: Text(
                  label == 'Cash'
                      ? '₹' + balanceVal.toString()
                      : balanceVal.toString() + ' ' + label,
                  style: new TextStyle(fontSize: 12, color: Colors.white),
                ),
              ),
            ),
            Text(
              flyyWalletCompleteData.rewardType,
              style: new TextStyle(fontSize: 12, color: Colors.white),
            )
          ],
        ),
      );
    }
  }
}
